<!--![valknut](.github/images/valknut.svg)-->

<p align="center">
  <img src=".github/images/valknut.svg" alt='Valknut' />
</p>

<h1 align="center">Draugr</h1>

<!--# Draugr-->


| [![Version](https://img.shields.io/static/v1?label=&message=0.1.1&color=377EF0&style=for-the-badge)](https://github.com/../../releases) | [![Documentation](https://img.shields.io/static/v1?label=&message=docs&color=EE4C2C&style=for-the-badge)](https://...github.io/../)  | ![Tests](https://github.com/../../workflows/test/badge.svg) | [![codecov](https://codecov.io/gh/../../branch/master/graph/badge.svg?token=..)](https://codecov.io/gh/../..) | [![codebeat badge](https://codebeat.co/badges/..)](https://codebeat.co/projects/github-com-..-..-master) | [![PyPI](https://img.shields.io/static/v1?label=&message=PyPI&color=377EF0&style=for-the-badge)](https://pypi.org/project/draugr/) | [![Python](https://img.shields.io/static/v1?label=&message=>=3.7&color=377EF0&style=for-the-badge&logo=python&logoColor=F8C63D)](https://www.python.org/) | [![PyTorch](https://img.shields.io/static/v1?label=&message=>=1.3.0&color=EE4C2C&style=for-the-badge)](https://pytorch.org/) | [![Docker](https://img.shields.io/static/v1?label=&message=docker&color=309cef&style=for-the-badge)](https://hub.docker.com/r/../..) |
|---|---|---|---|---|---|---|---|---|

| Workflows |
|-----------|
| ![Publish Python 🐍 distributions 📦 to PyPI and TestPyPI](https://github.com/cnheider/draugr/workflows/Publish%20Python%20%F0%9F%90%8D%20distributions%20%F0%9F%93%A6%20to%20PyPI%20and%20TestPyPI/badge.svg) |
| ![On Push Any Documentation Check](https://github.com/cnheider/draugr/workflows/On%20Push%20Any%20Documentation%20Check/badge.svg) |
|  ![CodeQL](https://github.com/cnheider/draugr/workflows/CodeQL/badge.svg) |


A utility package for...

- pytorch stuff
- visualisations
- plotting directly in your terminal
- python in general
- opencv images
- numpy array functions

https://en.wikipedia.org/wiki/Draugr

```bash
pip install draugr
```

OR

to include any of the dependencies include functionality in extras like so

```bash
pip install "draugr[drawer,writers]"
```

for drawer and writer functionalities and their dependencies

### [Drawers](draugr/drawers)

## [Samples](samples)
